pub enum TickOutcome {
Clean,
AgentFailed,
Unattributed,
}Expand description
What one PipelineWorld::tick did.
Variants
Clean
Every system ran to completion.
AgentFailed
A system panicked and the agent responsible was failed; the rest of the world is unaffected and can keep being driven.
Unattributed
A system panicked with no agent in scope, so nothing could be failed. Re-ticking would just re-panic.